<?php

namespace App\Controller;

use App\Connexion;
use App\Gateway\AuthGateway;
use App\Gateway\TacticInfoGateway;
use App\Http\HttpResponse;
use App\Http\ViewHttpResponse;
use App\Model\AuthModel;
use App\Model\TacticModel;
use App\Gateway\TeamGateway;
use App\Model\TeamModel;
use App\Session\SessionHandle;
use App\Controller\Sub\EditorController;

class UserController extends VisitorController {
    private TacticModel $tacticMdl;

    public function __construct()
    {
        $con = new Connexion(get_database());
        $this->tacticMdl = new TacticModel(new TacticInfoGateway($con));
    }

    public function home(): HttpResponse {
        $listTactic = $this->tacticMdl->getLast(5);
        return ViewHttpResponse::twig("home.twig", ["recentTactic" => $listTactic]);
    }

    public function view(int $id, SessionHandle $session): HttpResponse {
        $model = new TacticModel(new TacticInfoGateway(new Connexion(get_database())));
        return (new Sub\VisualizerController($model))->visualize($id, $session);
    }

    public function edit(int $id, SessionHandle $session): HttpResponse {
        $model = new TacticModel(new TacticInfoGateway(new Connexion(get_database())));
        return (new EditorController($model))->edit($id, $session);
    }

    public function create(SessionHandle $session): HttpResponse {
        $model = new TacticModel(new TacticInfoGateway(new Connexion(get_database())));
        return (new EditorController($model))->createNew($session);
    }

    public function open(int $id, SessionHandle $session): HttpResponse {
        $model = new TacticModel(new TacticInfoGateway(new Connexion(get_database())));
        return (new Sub\VisualizerController($model))->visualize($id, $session);
    }

    public function createTeam(): HttpResponse {
        $model = new TeamModel(new TeamGateway(new Connexion(get_database())));
        $ctrl = new Sub\TeamController($model);
        if ($_SERVER['REQUEST_METHOD'] === 'GET') {
            return $ctrl->displaySubmitTeam();
        }
        return $ctrl->submitTeam($_POST);
    }

    public function listTeams(): HttpResponse {
        $model = new TeamModel(new TeamGateway(new Connexion(get_database())));
        $ctrl = new Sub\TeamController($model);
        if ($_SERVER['REQUEST_METHOD'] === 'GET') {
            return $ctrl->displayListTeamByName();
        }
        return $ctrl->listTeamByName($_POST);
    }

    public function getTeam(int $id): HttpResponse {
        $model = new TeamModel(new TeamGateway(new Connexion(get_database())));
        $ctrl = new Sub\TeamController($model);
        return $ctrl->getTeam($id);
    }
}
